@@ -166,7 +166,21 @@ ACB_INLINE int
 acb_equal(const acb_t x, const acb_t y)
 {
     return arb_equal(acb_realref(x), acb_realref(y)) &&
-            arb_equal(acb_imagref(x), acb_imagref(y));
+           arb_equal(acb_imagref(x), acb_imagref(y));
+}
+
+ACB_INLINE int
+acb_eq(const acb_t x, const acb_t y)
+{
+    return arb_eq(acb_realref(x), acb_realref(y)) &&
+           arb_eq(acb_imagref(x), acb_imagref(y));
+}
+
+ACB_INLINE int
+acb_ne(const acb_t x, const acb_t y)
+{
+    return arb_ne(acb_realref(x), acb_realref(y)) ||
+           arb_ne(acb_imagref(x), acb_imagref(y));
 }
 
 ACB_INLINE int
@@ -834,6 +848,15 @@ void acb_randtest_special(acb_t z, flint_rand_t state, long prec, long mag_bits)
 
 void acb_randtest_precise(acb_t z, flint_rand_t state, long prec, long mag_bits);
 
+long acb_rel_error_bits(const acb_t x);
+
+ARB_INLINE long
+acb_rel_accuracy_bits(const acb_t x)
+{
+    return -acb_rel_error_bits(x);
+}
+
+
 ACB_INLINE long
 acb_bits(const acb_t x)
 {
