@@ -125,6 +125,10 @@ acb_poly_truncate(acb_poly_t poly, long newlen)
     }
 }
 
+void _acb_poly_majorant(arb_ptr res, acb_srcptr vec, long len, long prec);
+
+void acb_poly_majorant(arb_poly_t res, const acb_poly_t poly, long prec);
+
 void acb_poly_printd(const acb_poly_t poly, long digits);
 
 void _acb_poly_evaluate_horner(acb_t res, acb_srcptr f, long len, const acb_t a, long prec);
@@ -197,7 +201,7 @@ int acb_poly_overlaps(const acb_poly_t poly1, const acb_poly_t poly2);
 int acb_poly_contains(const acb_poly_t poly1, const acb_poly_t poly2);
 
 ACB_POLY_INLINE int
-acb_poly_is_real(acb_poly_t poly)
+acb_poly_is_real(const acb_poly_t poly)
 {
     return _acb_vec_is_real(poly->coeffs, poly->length);
 }
@@ -208,6 +212,8 @@ void _acb_poly_add(acb_ptr res, acb_srcptr poly1, long len1,
 void acb_poly_add(acb_poly_t res, const acb_poly_t poly1,
               const acb_poly_t poly2, long prec);
 
+void acb_poly_add_si(acb_poly_t res, const acb_poly_t poly, long c, long prec);
+
 void _acb_poly_sub(acb_ptr res, acb_srcptr poly1, long len1,
     acb_srcptr poly2, long len2, long prec);
 
@@ -489,16 +495,16 @@ void _acb_poly_exp_series(acb_ptr f, acb_srcptr h, long hlen, long n, long prec)
 void acb_poly_exp_series(acb_poly_t f, const acb_poly_t h, long n, long prec);
 
 void _acb_poly_sin_cos_series_basecase(acb_ptr s,
-                                    acb_ptr c, acb_srcptr h, long hlen, long n, long prec);
+                                    acb_ptr c, acb_srcptr h, long hlen, long n, long prec, int times_pi);
 
 void acb_poly_sin_cos_series_basecase(acb_poly_t s, acb_poly_t c,
-        const acb_poly_t h, long n, long prec);
+        const acb_poly_t h, long n, long prec, int times_pi);
 
 void _acb_poly_sin_cos_series_tangent(acb_ptr s, acb_ptr c,
-                        const acb_srcptr h, long hlen, long len, long prec);
+                        const acb_srcptr h, long hlen, long len, long prec, int times_pi);
 
 void acb_poly_sin_cos_series_tangent(acb_poly_t s, acb_poly_t c,
-                                    const acb_poly_t h, long n, long prec);
+                                    const acb_poly_t h, long n, long prec, int times_pi);
 
 void _acb_poly_sin_cos_series(acb_ptr s, acb_ptr c,
                         const acb_srcptr h, long hlen, long len, long prec);
@@ -514,6 +520,20 @@ void _acb_poly_cos_series(acb_ptr g, acb_srcptr h, long hlen, long n, long prec)
 
 void acb_poly_cos_series(acb_poly_t g, const acb_poly_t h, long n, long prec);
 
+void _acb_poly_sin_cos_pi_series(acb_ptr s, acb_ptr c,
+                        const acb_srcptr h, long hlen, long len, long prec);
+
+void acb_poly_sin_cos_pi_series(acb_poly_t s, acb_poly_t c,
+                                    const acb_poly_t h, long n, long prec);
+
+void _acb_poly_sin_pi_series(acb_ptr g, acb_srcptr h, long hlen, long n, long prec);
+
+void acb_poly_sin_pi_series(acb_poly_t g, const acb_poly_t h, long n, long prec);
+
+void _acb_poly_cos_pi_series(acb_ptr g, acb_srcptr h, long hlen, long n, long prec);
+
+void acb_poly_cos_pi_series(acb_poly_t g, const acb_poly_t h, long n, long prec);
+
 void _acb_poly_tan_series(acb_ptr g, acb_srcptr h, long hlen, long len, long prec);
 
 void acb_poly_tan_series(acb_poly_t g, const acb_poly_t h, long n, long prec);
