@@ -122,6 +122,13 @@ arb_equal(const arb_t x, const arb_t y)
            mag_equal(arb_radref(x), arb_radref(y));
 }
 
+int arb_eq(const arb_t x, const arb_t y);
+int arb_ne(const arb_t x, const arb_t y);
+int arb_lt(const arb_t x, const arb_t y);
+int arb_le(const arb_t x, const arb_t y);
+int arb_gt(const arb_t x, const arb_t y);
+int arb_ge(const arb_t x, const arb_t y);
+
 ARB_INLINE void
 arb_zero(arb_t x)
 {
@@ -658,7 +665,7 @@ void arb_chebyshev_u2_ui(arb_t a, arb_t b, ulong n, const arb_t x, long prec);
                 arb_init(name ## _cached_value); \
                 flint_register_cleanup_function(name ## _cleanup); \
             } \
-            comp_func(name ## _cached_value, prec); \
+            comp_func(name ## _cached_value, prec + 32); \
             name ## _cached_prec = prec; \
         } \
         arb_set_round(x, name ## _cached_value, prec); \
