@@ -167,6 +167,12 @@ int _arb_poly_overlaps(arb_srcptr poly1, long len1, arb_srcptr poly2, long len2)
 
 int arb_poly_overlaps(const arb_poly_t poly1, const arb_poly_t poly2);
 
+/* Bounds */
+
+void _arb_poly_majorant(arb_ptr res, arb_srcptr vec, long len, long prec);
+
+void arb_poly_majorant(arb_poly_t res, const arb_poly_t poly, long prec);
+
 /* IO */
 
 void arb_poly_printd(const arb_poly_t poly, long digits);
@@ -184,6 +190,8 @@ _arb_poly_add(arb_ptr res, arb_srcptr poly1, long len1,
 void arb_poly_add(arb_poly_t res, const arb_poly_t poly1,
               const arb_poly_t poly2, long prec);
 
+void arb_poly_add_si(arb_poly_t res, const arb_poly_t poly, long c, long prec);
+
 void _arb_poly_sub(arb_ptr res, arb_srcptr poly1, long len1,
     arb_srcptr poly2, long len2, long prec);
 
@@ -503,16 +511,16 @@ void _arb_poly_exp_series(arb_ptr f, arb_srcptr h, long hlen, long n, long prec)
 void arb_poly_exp_series(arb_poly_t f, const arb_poly_t h, long n, long prec);
 
 void _arb_poly_sin_cos_series_basecase(arb_ptr s,
-                                    arb_ptr c, arb_srcptr h, long hlen, long n, long prec);
+                                    arb_ptr c, arb_srcptr h, long hlen, long n, long prec, int times_pi);
 
 void arb_poly_sin_cos_series_basecase(arb_poly_t s, arb_poly_t c,
-        const arb_poly_t h, long n, long prec);
+        const arb_poly_t h, long n, long prec, int times_pi);
 
 void _arb_poly_sin_cos_series_tangent(arb_ptr s, arb_ptr c,
-                        const arb_srcptr h, long hlen, long len, long prec);
+                        const arb_srcptr h, long hlen, long len, long prec, int times_pi);
 
 void arb_poly_sin_cos_series_tangent(arb_poly_t s, arb_poly_t c,
-                                    const arb_poly_t h, long n, long prec);
+                                    const arb_poly_t h, long n, long prec, int times_pi);
 
 void _arb_poly_sin_cos_series(arb_ptr s, arb_ptr c,
                         const arb_srcptr h, long hlen, long len, long prec);
@@ -520,6 +528,12 @@ void _arb_poly_sin_cos_series(arb_ptr s, arb_ptr c,
 void arb_poly_sin_cos_series(arb_poly_t s, arb_poly_t c,
                                     const arb_poly_t h, long n, long prec);
 
+void _arb_poly_sin_cos_pi_series(arb_ptr s, arb_ptr c,
+                        const arb_srcptr h, long hlen, long len, long prec);
+
+void arb_poly_sin_cos_pi_series(arb_poly_t s, arb_poly_t c,
+                                    const arb_poly_t h, long n, long prec);
+
 void _arb_poly_sin_series(arb_ptr g, arb_srcptr h, long hlen, long n, long prec);
 
 void arb_poly_sin_series(arb_poly_t g, const arb_poly_t h, long n, long prec);
@@ -528,6 +542,14 @@ void _arb_poly_cos_series(arb_ptr g, arb_srcptr h, long hlen, long n, long prec)
 
 void arb_poly_cos_series(arb_poly_t g, const arb_poly_t h, long n, long prec);
 
+void _arb_poly_sin_pi_series(arb_ptr g, arb_srcptr h, long hlen, long n, long prec);
+
+void arb_poly_sin_pi_series(arb_poly_t g, const arb_poly_t h, long n, long prec);
+
+void _arb_poly_cos_pi_series(arb_ptr g, arb_srcptr h, long hlen, long n, long prec);
+
+void arb_poly_cos_pi_series(arb_poly_t g, const arb_poly_t h, long n, long prec);
+
 void _arb_poly_tan_series(arb_ptr g, arb_srcptr h, long hlen, long len, long prec);
 
 void arb_poly_tan_series(arb_poly_t g, const arb_poly_t h, long n, long prec);
